from http import HTTPStatus

RETRYABLE_STATUS_CODES = [
    HTTPStatus.TOO_MANY_REQUESTS,
    HTTPStatus.BAD_GATEWAY,
    HTTPStatus.SERVICE_UNAVAILABLE,
    HTTPStatus.GATEWAY_TIMEOUT,
]

MAX_RETRY_ATTEMPTS = 3
RETRY_BACKOFF_BASE = 2



from datetime import date


def get_default_date() -> str:
    """
    Returns today's date in YYYY-MM-DD format.

    :return: Today's date as string
    """
    return date.today().strftime("%Y-%m-%d")



from requests.auth import HTTPBasicAuth


def get_auth(username: str, password: str) -> HTTPBasicAuth:
    """
    Returns HTTPBasicAuth instance with given credentials.

    :param username:
    :param password:
    :return: HTTPBasicAuth instance
    """
    return HTTPBasicAuth(username, password)
